

# NSF disclaimer
    This project is supported by the National Science Fundation under Grant N0 ECCS-0725746. Any opinions, findings, and conclusions or recommendations expressed in this material are those of the authors and do not necessarily reflect the views of the National Science Foundation.

# Authors' disclaimers 
The authors decline responsibility for mistakes, incompleteness or lack of quality of the information provided in the pages of the workbench or the challenge websites. The authors are not responsible for any contents linked or referred to from the pages of this site, which are external to this site. The authors intended not to use any copyrighted material for the publication or, if not possible, to indicate the copyright of the respective object. The copyright for any material created by the authors is reserved. The authors intended not to violate any patent rights or, if not possible, to indicate the patents of the respective objects. The payment of royalties or other fees for use of methods, which may be protected by patents, remains the responsibility of the users.

ALL INFORMATION, SOFTWARE, DOCUMENTATION, AND DATA ARE PROVIDED "AS-IS" THE ORGANIZERS DISCLAIM ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL ISABELLE GUYON AND/OR OTHER ORGANIZERS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF SOFTWARE, DOCUMENTS, MATERIALS, PUBLICATIONS, OR INFORMATION MADE AVAILABLE THROUGH THE WORKBENCH.
    Participation in the organized challenge(s) is not-binding and without obligation. Parts of the pages or the complete publication and information might be extended, changed or partly or completely deleted by the authors without separate announcement. However, participants who identified themselves with valid email addresses will get notices about changes that will affect the challenge(s).

# Privacy policy

    Names provided in the submission form are published in the result table. Participants who do not want to be identified during the development phase may provide nicknames. Email addresses are used to uniquely identify participants and provide notices concerning the challenge. They are not published in the result table and will not otherwise be publicly disclosed, unless explicitly authorized by the participant. The participants will however be required to identify themselves to be part of the final competition ranking, i.e. all final submissions must be made with the real participant name

# Credits

    We are very grateful to our sponsors who made this project possible. Any new financial contribution will be used towards providing prizes and travel money for successful challenge participants who need support. Help us, become a sponsor!


# NSF
    The causality workbench project is supported by the National Science Fundation under Grant N0 ECCS-0725746. Any opinions, findings, and conclusions or recommendations expressed in this material are those of the authors and do not necessarily reflect the views of the National Science Foundation.


    WCCI Pascal Microsoft Clopinet Unipen ETH MisterP Services HDC France Telecom
    Project team:
    Constantin F. Aliferis (Vanderbilt University, Tennessee),
    Gregory F. Cooper (University of Pittsburgh, Pennsylvania),
    André Elisseeff (IBM Research, Switzerland),
    Jean-Philippe Pellet (IBM Research, Switzerland),
    Alexander Statnikov (Vanderbilt University, Tennessee),
    Peter Spirtes (Carnegie Mellon University, Pennsylvania).

#   Coordinator

    Isabelle Guyon
    Clopinet Enterprises
    955, Creston Road,
    Berkeley, CA 94708, U.S.A.
    Tel/Fax: (510) 524 6211
    causality @ clopinet . com
    The web site design of Steve Gunn (University of Southampton, UK), formerly used for the NIPS2003 feature selection challenge, was adapted and improved by Olivier Guyon (MisterP.net, France). We are thankful to Thomas Fuchs (ETH Zurich, Switzerland) for administering the computer resources.

# The advisors, beta-testers, and other contributors to the project are very gratefully acknowledged
    Hans Bitter (Roche Palo Alto, California),
    Alexander Borisov (Intel, Nizhny Novgorod, Russia),
    Marc Boullé (France Télecom, France),
    Nicolas Brodu (Unitersité de Renne, France),
    Joachim Buhmann (ETH Zurich, Switzerland),
    Joaquin Quiñonero Candela (Microsoft Research, UK),
    Gavin Cawley (University of East Anglia, UK),
    Gideon Dror (Academic College of Tel-Aviv-Yaffo, Israel),
    Patrik Hoyer (University of Helsinki, Finland),
    Amir Reza Saffari Azar (Graz University of Technology, Austria),
    Richard Scheines (Carnegie Mellon University, Pennsylvania),
    Lambert Schomaker (University of Groningen, The Netherlands),
    Joerg Wichard (Institute of Molecular Pharmacology, Berlin, Germany).

    We are very grateful to the people and institutions who provided datasets for our challenges, including:
    SIDO: The DTP AIDS Antiviral Screen program of the US National Cancer Institute (NCI).
    CINA: The census bureau and Ronny Kohavi and Barry Becker who extracted the data.
    CYTO: Karens Sachs and her co-authors (Stanford University).
    SIGNET: Jerry W. Jenkins and Abhishek Soni (CFD Research, Alabama, USA). 


# Source and licence

http://clopinet.com/isabelle/Projects/agnostic/